@@ -38,23 +38,23 @@ class Database:
         self.table_params = Table(
             f"{self.prefix}_{self.table_params}", MetaData(),
             Column('prefix', String, primary_key=True),
-            Column('a', Float),
-            Column('b', Float),
-            Column('h', Float),
+            Column('a', Float, nullable=False),
+            Column('b', Float, nullable=False),
+            Column('h', Float, nullable=False),
         )
 
         self.table_corpus = Table(
             f"{self.prefix}_{self.table_corpus}", MetaData(),
             Column(self.field_features, self.type_features, primary_key=True),
             Column(self.field_classes, self.type_classes, primary_key=True),
-            Column(self.field_weights, Float),
+            Column(self.field_weights, Float, nullable=False),
         )
 
         self.table_weights = Table(
             f"{self.prefix}_{self.table_weights}", MetaData(),
             Column(self.field_features, self.type_features, primary_key=True),
             Column(self.field_classes, self.type_classes, primary_key=True),
-            Column(self.field_weights, Float),
+            Column(self.field_weights, Float, nullable=False),
         )
 
         if not self.exists(self.table_params):
